IdTreeMeta
==========

.. currentmodule:: dash_component_template.idtree

.. autoclass:: IdTreeMeta
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~IdTreeMeta.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
